@@ -2,8 +2,6 @@ import json
 from abc import ABC, abstractmethod
 from typing import List, Union
 
-from aio_pika import Message
-
 from .enums import ContentType
 
 
@@ -11,7 +9,7 @@ class BaseSerializer(ABC):
     content_type: List[Union[ContentType, None]] = None
 
     @abstractmethod
-    async def serialize(self, data: bytes) -> Message:
+    async def serialize(self, data: bytes):
         raise NotImplementedError
 
     @abstractmethod
@@ -22,14 +20,8 @@ class BaseSerializer(ABC):
 class RawSerializer(BaseSerializer):
     content_type = [ContentType.TEXT, None]
 
-    async def serialize(self, data: Union[str, bytes]) -> Message:
-        if isinstance(data, str):
-            data = data.encode()
-        elif data is None:
-            data = b""
-        else:
-            data = str(data).encode()
-        return Message(data, content_type=self.content_type[0])
+    async def serialize(self, data: Union[str, bytes]):
+        return data
 
     async def deserialize(self, data: bytes):
         return data
@@ -38,8 +30,8 @@ class RawSerializer(BaseSerializer):
 class JSONSerializer(BaseSerializer):
     content_type = [ContentType.JSON]
 
-    async def serialize(self, data: Union[dict, list]) -> Message:
-        return Message(json.dumps(data).encode(), content_type=self.content_type[0])
+    async def serialize(self, data: Union[dict, list, int, float, str]) -> bytes:
+        return json.dumps(data).encode()
 
     async def deserialize(self, data: bytes):
         return json.loads(data)
